@@ -1,5 +1,5 @@
 from .commasv import CSVSerializer
-from .datatables import DatatablesSerializer
+from .datatables import MapentityDatatableSerializer
 from .gpx import GPXSerializer
 from .helpers import json_django_dumps, plain_text, smart_plain_text
 from .shapefile import ZipShapeSerializer
@@ -8,6 +8,6 @@ __all__ = ['plain_text',
            'smart_plain_text',
            'CSVSerializer',
            'GPXSerializer',
-           'DatatablesSerializer',
+           'MapentityDatatableSerializer',
            'ZipShapeSerializer',
            'json_django_dumps']
