@@ -1,6 +1,5 @@
 from .api import (
     MapEntityLayer,
-    MapEntityJsonList,
     MapEntityViewSet
 )
 from .base import (
@@ -25,7 +24,7 @@ from .generic import (
     MapEntityUpdate,
     MapEntityDelete,
 )
-from .logentry import LogEntryList
+from .logentry import LogEntryList, LogEntryViewSet
 from .mixins import (
     HttpJSONResponse,
     JSONResponseMixin,
@@ -36,7 +35,6 @@ from .mixins import (
 MAPENTITY_GENERIC_VIEWS = [
     MapEntityLayer,
     MapEntityList,
-    MapEntityJsonList,
     MapEntityFormat,
     MapEntityMapImage,
     MapEntityDocument,
@@ -62,22 +60,17 @@ __all__ = [
     'MapEntityDetail',
     'MapEntityUpdate',
     'MapEntityDelete',
-
     'MapEntityLayer',
-    'MapEntityJsonList',
     'MapEntityViewSet',
-
     'HttpJSONResponse',
     'JSONResponseMixin',
     'LastModifiedMixin',
     'ModelViewMixin',
     'MAPENTITY_GENERIC_VIEWS',
-
     'ServeAttachment',
     'JSSettings',
     'map_screenshot',
-    'convert',
     'history_delete',
-
     'LogEntryList',
+    'LogEntryViewSet'
 ]
